@@ -10,6 +10,16 @@ class DepotType(Enum):
     图床
     url: https://catbox.moe/
     """
+    PngCm = auto()
+    """
+    图床
+    url: https://png.cm/
+    """
+    Riyugo = auto()
+    """
+    链接存在有效期
+    url: https://riyugo.com/
+    """
     Ai58 = auto()
     """
     58同城客服, 在线上传图片
